import numpy  # pylint: disable=import-error


def mask_by_nan(data, band):
    return ~numpy.isnan(data[band])


def mask_by_emad_nan(data, band, band_mapper=None):
    if band_mapper:
        emad = band_mapper("EMAD")
    else:
        emad = "EMAD"
    return ~numpy.isnan(data[emad])


import datetime
from typing import Sequence, Tuple


def rolling_window_6day(available_dates: Sequence[datetime.datetime], layer_cfg) -> Tuple[datetime.datetime, datetime.datetime]:
    days = available_dates[-6:]
    start, _ = layer_cfg.search_times(days[-6])
    _, end = layer_cfg.search_times(days[-1])
    return (start, end)



reslim_c3_s2 = {
    "wms": {
        "zoomed_out_fill_colour": [150, 180, 200, 160],
        "min_zoom_factor": 15.0,
        # "max_datasets": 16, # Defaults to no dataset limit
    },
    "wcs": {
        # "max_datasets": 16, # Defaults to no dataset limit
    },
}


